@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 from typing import Tuple
 
-from pygismeteo_base import constants, types, validators
+from . import constants, types, validators
 
 
 class BaseHttpClient:
