@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import List, Optional
 
 from pydantic import BaseModel, Field
@@ -14,18 +16,18 @@ class SubDistrict(BaseModel):
 
 
 class Country(BaseModel):
-    name: Optional[str]
+    name: str
     code: str
-    name_p: Optional[str] = Field(..., alias="nameP")
+    name_p: str = Field(..., alias="nameP")
 
 
 class ModelItem(BaseModel):
-    district: Optional[District]
+    district: Optional[District] = Field(default=None)
     id: int
-    sub_district: Optional[SubDistrict]
+    sub_district: Optional[SubDistrict] = Field(default=None)
     url: str
-    name_p: Optional[str] = Field(..., alias="nameP")
-    name: Optional[str]
+    name_p: str = Field(..., alias="nameP")
+    name: str
     distance: float
     kind: str
     country: Country
