@@ -1,4 +1,6 @@
-from pygismeteo_base import types, validators
+from __future__ import annotations
+
+from . import types, validators
 
 
 class Search:
