@@ -1,14 +1,16 @@
+from __future__ import annotations
+
 from ipaddress import IPv4Address
 from typing import Optional
 
 from pydantic import BaseModel, Field, PositiveInt
 
-from pygismeteo_base import types
+from . import types
 
 
 class Settings(BaseModel):
-    lang: Optional[types.Lang]
-    token: Optional[str]
+    lang: Optional[types.Lang] = Field(...)
+    token: Optional[str] = Field(...)
 
     class Config:
         anystr_strip_whitespace = True
